@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Session;
 # ABSTRACT: Context of work for database interactions
-$Neo4j::Driver::Session::VERSION = '0.38';
+$Neo4j::Driver::Session::VERSION = '0.39';
 
 use Carp qw(croak);
 our @CARP_NOT = qw(
@@ -28,7 +28,7 @@ sub new {
 	# uncoverable pod (private method)
 	my ($class, $driver) = @_;
 	
-	return Neo4j::Driver::Session::Bolt->new($driver) if $driver->{uri}->scheme eq 'bolt';
+	return Neo4j::Driver::Session::Bolt->new($driver) if $driver->config('uri')->scheme eq 'bolt';
 	return Neo4j::Driver::Session::HTTP->new($driver);
 }
 
@@ -70,7 +70,7 @@ sub _execute {
 	my (@r, $r);
 	my $wantarray = wantarray;
 	my $time_stop = Time::HiRes::time
-		+ ($self->{driver}->{max_transaction_retry_time} // 30);  # seconds
+		+ ($self->{driver}->config('max_transaction_retry_time') // 30);  # seconds
 	my $tries = 0;
 	my $success = 0;
 	do {
@@ -153,7 +153,7 @@ sub new {
 	my ($class, $driver) = @_;
 	
 	return bless {
-		cypher_params_v2 => $driver->{cypher_params_v2},
+		cypher_params_v2 => $driver->config('cypher_params'),
 		driver => $driver,
 		net => Neo4j::Driver::Net::Bolt->new($driver),
 	}, $class;
@@ -176,7 +176,7 @@ sub new {
 	my ($class, $driver) = @_;
 	
 	return bless {
-		cypher_params_v2 => $driver->{cypher_params_v2},
+		cypher_params_v2 => $driver->config('cypher_params'),
 		driver => $driver,
 		net => Neo4j::Driver::Net::HTTP->new($driver),
 	}, $class;
@@ -202,7 +202,7 @@ Neo4j::Driver::Session - Context of work for database interactions
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
@@ -313,7 +313,7 @@ The driver will automatically commit the transaction when the
 provided subroutine finishes execution. Any error raised during
 execution will result in a rollback attempt. For certain kinds
 of errors, the given subroutine will be retried with exponential
-backoff until L<Neo4j::Driver/"max_transaction_retry_time">
+backoff until L<Neo4j::Driver::Config/"max_transaction_retry_time">
 (see L<Neo4j::Error/"is_retryable"> for the complete list).
 Because of this, the given subroutine needs to be B<idempotent>
 (S<i. e.>, have the same effect regardless of how many times
